DROP TABLE t_clob
/
CREATE TABLE t_clob(
     file_name  VARCHAR2(200)
    ,file_data NCLOB
    ,file_csid  INTEGER
    );


CREATE OR REPLACE PROCEDURE loadCLOB
    (
     p_file_name    IN VARCHAR2
    ,p_csid         IN INTEGER := 0
    )
AS

    v_clob         NCLOB;
    v_src_file      BFILE;
    v_error_out     INTEGER;
    dest_offset     INTEGER := 1;
    src_offset      INTEGER := 1;
    lang_context    INTEGER := dbms_lob.default_lang_ctx;

BEGIN
	dbms_lob.createTemporary( v_clob,TRUE,dbms_lob.SESSION );
    INSERT INTO t_clob(
         file_name
        ,file_data
        ,file_csid
        )
     VALUES (
         p_file_name
        ,NULL
        ,p_csid
        );

    v_src_file := bfilename( 'PFAD_REPORTS', p_file_name );
    dbms_lob.fileOpen( v_src_file, dbms_lob.file_readonly );
    dbms_lob.loadClobFromfile(
         v_clob
        ,v_src_file
        ,dbms_lob.lobMaxSize
        ,dest_offset
        ,src_offset
        ,p_csid
        ,lang_context
        ,v_error_out
        );
    dbms_lob.fileCloseAll() ;

    UPDATE  t_clob
    SET     file_data = v_clob
    WHERE   file_name = p_file_name;

    dbms_lob.freeTemporary(v_clob);

END loadCLOB;
/
SHOW ERRORS

BEGIN
    loadCLOB( 'test_UTF-8.txt',871);
    loadCLOB( 'test_UTF-16_BigEndian_ohneBOM.txt',178);
    loadCLOB( 'test_Unicode_ASCII-Escaped.txt',178);

END;
/

INSERT INTO t_clob(
     file_name
    ,file_data
    ,file_csid
    )
 VALUES (
     'test_Unistr.txt'
    ,NULL
    ,871
    );

DECLARE
    v_tmp_clob  NCLOB;
    v_file_name VARCHAR2(200) := 'test_Unistr.txt';
BEGIN
    dbms_lob.createTemporary( v_tmp_clob,TRUE,dbms_lob.session );
    v_tmp_clob := UNISTR('Testdatei \00E4\00F6\00FC? \0152\03A3\03CE\0497\0639\06DE\FBDC\FEFC');
    UPDATE  t_clob
    SET     file_data = v_tmp_clob
    WHERE   file_name = v_file_name;
    dbms_lob.freeTemporary( v_tmp_clob );
END;
/

COMMIT;

DECLARE
    v_clob                  NCLOB;
    v_filename              t_clob.file_name%TYPE;
    v_fileHandle            utl_file.FILE_TYPE;
BEGIN
    FOR r IN (
        SELECT  file_name
               ,file_data
               ,file_csid
        FROM    t_clob
        )
    LOOP
        v_fileHandle := utl_file.fopen ('PFAD_REPORTS', 'raw_'||r.file_name, 'wb', 32767);
        utl_file.put_raw(v_fileHandle, utl_raw.cast_to_raw(r.file_data));
        utl_file.fclose(v_fileHandle);

        v_fileHandle := utl_file.fopen ('PFAD_REPORTS', 'put_'||r.file_name, 'w', 32767);
        utl_file.put(v_fileHandle,r.file_data);
        utl_file.fclose(v_fileHandle);

        dbms_xslprocessor.clob2file(r.file_data,'PFAD_REPORTS','c2f_'||r.file_name,r.file_csid);
    END LOOP;
END;
/

SELECT  file_name
       ,file_data
       ,DUMP(TO_NCHAR(file_data))
FROM    t_clob;

